@@ -29,7 +29,9 @@
 
 #include <config.h>
 #include <stdlib.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <string.h>
 #include <stdarg.h>
 #include <locale.h>
@@ -598,7 +600,7 @@ gnome_font_face_find_closest_from_weight_slant (const guchar *family, GnomeFontW
 
 	for (l = map->fonts; l != NULL; l = l->next) {
 		entry = (GPFontEntry *) l->data;
-		if (!strcasecmp (family, entry->familyname)) {
+		if (!g_strcasecmp (family, entry->familyname)) {
 			if (entry->type == GP_FONT_ENTRY_ALIAS)
 				entry = ((GPFontEntryAlias *) entry)->ref;
 			dist = abs (weight - entry->Weight) +
