@@ -24,9 +24,9 @@
  */
 
 
-#include "config.h"
+#include <config.h>
 #include <glib.h>
-#include "gnome-print-i18n.h"
+#include <libgnomeprint/gnome-print-i18n.h>
 
 char *
 libgnomeprint_gettext (const char *msgid)
