@@ -22,13 +22,10 @@
  *    Lauris Kaplinski <lauris@ximian.com>
  *    Chema Celorio <chema@celorio.com>
  *
- *  Copyright (C) 1999-2001 Ximian Inc. and authors
- *
+ *  Copyright (C) 1999-2003 Ximian Inc. and authors
  */
 
-#define __GNOME_PRINT_STDAPI_C__
-
-#include "config.h"
+#include <config.h>
 #include <math.h>
 #include <string.h>
 
@@ -60,20 +57,11 @@ gnome_print_clip (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_close_all (pc->gc);
-	ret = gnome_print_clip_bpath_rule (pc, gp_gc_get_currentpath (pc->gc), ART_WIND_RULE_ODDEVEN);
+	ret = gnome_print_clip_bpath_rule (pc, gp_gc_get_currentpath (pc->gc), ART_WIND_RULE_NONZERO);
 	gp_gc_newpath (pc->gc);
 
 	return ret;
@@ -102,16 +90,7 @@ gnome_print_eoclip (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_close_all (pc->gc);
@@ -144,16 +123,7 @@ gnome_print_fill (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_close_all (pc->gc);
@@ -186,16 +156,7 @@ gnome_print_eofill (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_close_all (pc->gc);
@@ -226,16 +187,7 @@ gnome_print_stroke (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	ret = gnome_print_stroke_bpath (pc, gp_gc_get_currentpath (pc->gc));
@@ -266,16 +218,7 @@ gnome_print_grayimage (GnomePrintContext *pc, const guchar *data, int width, int
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (data != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (width > 0, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (height > 0, GNOME_PRINT_ERROR_BADVALUE);
@@ -306,16 +249,7 @@ gnome_print_rgbimage (GnomePrintContext *pc, const guchar *data, int width, int
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (data != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (width > 0, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (height > 0, GNOME_PRINT_ERROR_BADVALUE);
@@ -347,16 +281,7 @@ gnome_print_rgbaimage (GnomePrintContext *pc, const guchar *data, int width, int
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (data != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (width > 0, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (height > 0, GNOME_PRINT_ERROR_BADVALUE);
@@ -387,16 +312,7 @@ gnome_print_concat (GnomePrintContext *pc, const gdouble *matrix)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (matrix != NULL, GNOME_PRINT_ERROR_BADVALUE);
 
 	gp_gc_concat (pc->gc, matrix);
@@ -420,15 +336,7 @@ gnome_print_newpath (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_newpath (pc->gc);
 
@@ -453,15 +361,7 @@ gnome_print_moveto (GnomePrintContext *pc, double x, double y)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_moveto (pc->gc, x, y);
 
@@ -487,16 +387,7 @@ gnome_print_lineto (GnomePrintContext *pc, double x, double y)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpoint (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPOINT);
 
 	gp_gc_lineto (pc->gc, x, y);
@@ -528,16 +419,7 @@ gnome_print_curveto (GnomePrintContext *pc, double x1, double y1, double x2, dou
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpoint (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPOINT);
 
 	gp_gc_curveto (pc->gc, x1, y1, x2, y2, x3, y3);
@@ -563,16 +445,7 @@ gnome_print_closepath (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_closepath (pc->gc);
@@ -603,21 +476,13 @@ gnome_print_bpath (GnomePrintContext *pc, const ArtBpath *bpath, gboolean append
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (bpath != NULL, GNOME_PRINT_ERROR_BADVALUE);
 
 	if (!append) {
 		gp_gc_newpath (pc->gc);
-		if (bpath->code == ART_END) return GNOME_PRINT_OK;
+		if (bpath->code == ART_END)
+			return GNOME_PRINT_OK;
 		g_return_val_if_fail ((bpath->code == ART_MOVETO) || (bpath->code == ART_MOVETO_OPEN), GNOME_PRINT_ERROR_BADVALUE);
 	}
 
@@ -627,7 +492,8 @@ gnome_print_bpath (GnomePrintContext *pc, const ArtBpath *bpath, gboolean append
 		switch (bpath->code) {
 		case ART_MOVETO:
 		case ART_MOVETO_OPEN:
-			if (closed) gp_gc_closepath (pc->gc);
+			if (closed)
+				gp_gc_closepath (pc->gc);
 			closed = (bpath->code == ART_MOVETO);
 			gp_gc_moveto (pc->gc, bpath->x3, bpath->y3);
 			break;
@@ -645,7 +511,8 @@ gnome_print_bpath (GnomePrintContext *pc, const ArtBpath *bpath, gboolean append
 		bpath += 1;
 	}
 
-	if (closed) gp_gc_closepath (pc->gc);
+	if (closed)
+		gp_gc_closepath (pc->gc);
 
 	return GNOME_PRINT_OK;
 }
@@ -673,16 +540,7 @@ gnome_print_vpath (GnomePrintContext *pc, const ArtVpath *vpath, gboolean append
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (vpath != NULL, GNOME_PRINT_ERROR_BADVALUE);
 
 	if (!append) {
@@ -697,7 +555,8 @@ gnome_print_vpath (GnomePrintContext *pc, const ArtVpath *vpath, gboolean append
 		switch (vpath->code) {
 		case ART_MOVETO:
 		case ART_MOVETO_OPEN:
-			if (closed) gp_gc_closepath (pc->gc);
+			if (closed)
+				gp_gc_closepath (pc->gc);
 			closed = (vpath->code == ART_MOVETO);
 			gp_gc_moveto (pc->gc, vpath->x, vpath->y);
 			break;
@@ -712,7 +571,8 @@ gnome_print_vpath (GnomePrintContext *pc, const ArtVpath *vpath, gboolean append
 		vpath += 1;
 	}
 
-	if (closed) gp_gc_closepath (pc->gc);
+	if (closed)
+		gp_gc_closepath (pc->gc);
 
 	return GNOME_PRINT_OK;
 }
@@ -741,15 +601,7 @@ gnome_print_arcto (GnomePrintContext *pc, gdouble x, gdouble y, gdouble radius,
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail ((direction == 0) || (direction == 1), GNOME_PRINT_ERROR_BADVALUE);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	/* Find modulo 360 */
 	angle1 = fmod (angle1, 360.0);
@@ -759,7 +611,7 @@ gnome_print_arcto (GnomePrintContext *pc, gdouble x, gdouble y, gdouble radius,
 		gp_gc_moveto (pc->gc, x + radius * cos (angle1 * M_PI / 180.0), y + radius * sin (angle1 * M_PI / 180.0));
 	}
 
-	/* fixme: really use curveto's here */
+	/* FIXME: really use curveto's here (Lauris) */
 	if (!direction) {
 		/* CCW */
 		if (angle1 > angle2)
@@ -800,16 +652,7 @@ gnome_print_strokepath (GnomePrintContext *pc)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpath (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPATH);
 
 	gp_gc_strokepath (pc->gc);
@@ -837,15 +680,7 @@ gnome_print_setrgbcolor (GnomePrintContext *pc, double r, double g, double b)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_rgbcolor (pc->gc, r, g, b);
 
@@ -870,15 +705,7 @@ gnome_print_setopacity (GnomePrintContext *pc, double opacity)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_opacity (pc->gc, opacity);
 
@@ -906,15 +733,7 @@ gnome_print_setlinewidth (GnomePrintContext *pc, double width)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_linewidth (pc->gc, width);
 
@@ -939,15 +758,7 @@ gnome_print_setmiterlimit (GnomePrintContext *pc, double limit)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_miterlimit (pc->gc, limit);
 
@@ -974,15 +785,7 @@ gnome_print_setlinejoin (GnomePrintContext *pc, int jointype)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_linejoin (pc->gc, jointype);
 
@@ -1009,15 +812,7 @@ gnome_print_setlinecap (GnomePrintContext *pc, int captype)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	gp_gc_set_linecap (pc->gc, captype);
 
@@ -1050,16 +845,7 @@ gnome_print_setdash (GnomePrintContext *pc, int n_values, const double *values,
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail ((n_values == 0) || (values != NULL), GNOME_PRINT_ERROR_BADVALUE);
 
 	gp_gc_set_dash (pc->gc, n_values, values, offset);
@@ -1085,16 +871,7 @@ gnome_print_setfont (GnomePrintContext *pc, const GnomeFont *font)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (font != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (GNOME_IS_FONT (font), GNOME_PRINT_ERROR_BADVALUE);
 
@@ -1127,16 +904,7 @@ gnome_print_glyphlist (GnomePrintContext *pc, GnomeGlyphList * glyphlist)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpoint (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPOINT);
 	g_return_val_if_fail (glyphlist != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (GNOME_IS_GLYPHLIST (glyphlist), GNOME_PRINT_ERROR_BADVALUE);
@@ -1178,16 +946,7 @@ gnome_print_show (GnomePrintContext *pc, const guchar *text)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (text != NULL, GNOME_PRINT_ERROR_BADVALUE);
 
 	return gnome_print_show_sized (pc, text, strlen (text));
@@ -1219,21 +978,13 @@ gnome_print_show_sized (GnomePrintContext *pc, const guchar *text, int bytes)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
-
 	g_return_val_if_fail (gp_gc_has_currentpoint (pc->gc), GNOME_PRINT_ERROR_NOCURRENTPOINT);
 	g_return_val_if_fail (text != NULL, GNOME_PRINT_ERROR_BADVALUE);
 	g_return_val_if_fail (bytes >= 0, GNOME_PRINT_ERROR_BADVALUE);
 
-	if (bytes < 1) return GNOME_PRINT_OK;
+	if (bytes < 1)
+		return GNOME_PRINT_OK;
 
 	g_return_val_if_fail (g_utf8_validate (text, bytes, &invalid), GNOME_PRINT_ERROR_TEXTCORRUPT);
 
@@ -1268,15 +1019,7 @@ gnome_print_scale (GnomePrintContext *pc, double sx, double sy)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	art_affine_scale (dst, sx, sy);
 
@@ -1301,15 +1044,7 @@ gnome_print_rotate (GnomePrintContext *pc, gdouble theta)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	art_affine_rotate (dst, theta);
 
@@ -1335,15 +1070,7 @@ gnome_print_translate (GnomePrintContext *pc, double x, double y)
 	g_return_val_if_fail (pc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (GNOME_IS_PRINT_CONTEXT (pc), GNOME_PRINT_ERROR_BADCONTEXT);
 	g_return_val_if_fail (pc->gc != NULL, GNOME_PRINT_ERROR_BADCONTEXT);
-
-#ifdef ALLOW_BROKEN_PGL
-	if (!pc->haspage) {
-		g_warning ("file %s: line %d: Missing beginpage in print job", __FILE__, __LINE__);
-		gnome_print_beginpage (pc, "Unnamed");
-	}
-#else
 	g_return_val_if_fail (pc->haspage, GNOME_PRINT_ERROR_NOPAGE);
-#endif
 
 	art_affine_identity (dst);
 	dst[4] = x;
@@ -1356,6 +1083,21 @@ gnome_print_translate (GnomePrintContext *pc, double x, double y)
  * Convenience methods
  */
 
+/**
+ * gnome_print_line_stroked:
+ * @pc: A #GnomePrintContext
+ * @x0: X position of start point in user coordinates
+ * @y0: Y position of start point in user coordinates
+ * @x1: X position of end point in user coordinates
+ * @y1: Y position of end point in user coordinates
+ *
+ * A convenience function to draw a line.  Uses 
+ * #gnome_print_stroke to do the actual work.
+ * 
+ * Returns: #GNOME_PRINT_OK or positive value on success, negative error code
+ *          on failure.
+ *
+ **/
 gint
 gnome_print_line_stroked (GnomePrintContext *pc, gdouble x0, gdouble y0, gdouble x1, gdouble y1)
 {
@@ -1370,6 +1112,21 @@ gnome_print_line_stroked (GnomePrintContext *pc, gdouble x0, gdouble y0, gdouble
 	return gnome_print_stroke (pc);
 }
 
+/**
+ * gnome_print_rect_stroked:
+ * @pc: A #GnomePrintContext
+ * @x: X position of origin of rectangle in user coordinates
+ * @y: Y position of origin of rectangle in user coordinates
+ * @width: Width of the rectangle
+ * @height: Height of the rectange
+ *
+ * A convenience function to draw a rectangle. Uses 
+ * #gnome_print_stroke to do the actual work.
+ *
+ * Returns: #GNOME_PRINT_OK or positive value on success, negative error code
+ *          on failure. 
+ *
+ **/
 gint
 gnome_print_rect_stroked (GnomePrintContext *pc, gdouble x, gdouble y, gdouble width, gdouble height)
 {
@@ -1388,6 +1145,21 @@ gnome_print_rect_stroked (GnomePrintContext *pc, gdouble x, gdouble y, gdouble w
 	return gnome_print_stroke (pc);
 }
 
+/**
+ * gnome_print_rect_filled:
+ * @pc: A #GnomePrintContext
+ * @x: X position of origin of rectangle in user coordinates
+ * @y: Y position of origin of rectangle in user coordinates
+ * @width: Width of the rectangle
+ * @height: Height of the rectange
+ *
+ * A convenience function to draw a filled rectangle. Uses 
+ * #gnome_print_stroke to do the actual work.
+ *
+ * Returns: #GNOME_PRINT_OK or positive value on success, negative error code
+ *          on failure. 
+ *
+ **/
 gint
 gnome_print_rect_filled (GnomePrintContext *pc, gdouble x, gdouble y, gdouble width, gdouble height)
 {
