@@ -35,7 +35,7 @@
 
 /* Global variables */
 GPARoot * gpa_root = NULL;
-gboolean  initializing = FALSE;
+static gboolean initializing = FALSE;
 
 static GPANodeClass *parent_class;
 
